//This program code is released under GNU General Public License (GPL)
//(http://www.gnu.org/copyleft/gpl.html)
//(C) Wolfgang Gossel (2011)
// Muehlweg 49 
// D-06114 Halle
//or: Martin Luther University
//    Dept. Hydrogeology and Environmental Geology
//    V.-Seckendorff Platz 3
//    D-06120 Halle
//email: wolfgang.gossel@geo.uni-halle.de
//homepage: http://www.mo2geo.org

#include "gui2Frm.h"
#include <iostream>
#include <fstream>
#include <string>
#include <wx/wx.h>

using namespace std;

class projectFileAnalysis
{
    public:
        void analyzeProjectFileContent(string fileContent);
        long getIntNPER() const {return intNumPer;};
	long getIntITMUNI(){return intITMUnits;};
	long getIntLENUNI(){return intLengthUnits;};
        long getIntNLAY(){return intNumLayers;};
	long getIntNROW(){return intNumRows;};
	long getIntNCOL(){return intNumCols;};
	void getIntNSTP(long lngIntNumStep[]);
	long getIntTSMULT(){return intTimeStepMulti;};
	long getIntSAVEPERIODS(){return intSavePeriods;};
	double getDblPERLEN(){return dblPerLen;};
	double getDblTMUNIMULT(){return dblTimeUnitMult;};
	double getDblLENUNIMULT(){return dblLengthUnitMult;};
	double getDblXDist(){return dblXRasterDistance;};
	double getDblYDist(){return dblYRasterDistance;};
	double getDblRechargeMult(){return dblRechMult;};
	double getDblDischargeMult(){return dblDisMult;};
	double getDblXMin(){return dblXRasterMin;};
	double getDblYMin(){return dblYRasterMin;};
	wxString getStrPathProjectFile(){return strPathProjectFile;};
	wxString getStrPathProjectFilePre(){return strPathProjectFilePre;};
	wxString getStrPathProjectFilePost(){return strPathProjectFilePost;};
	wxString getStrPathProjectFileEx(){return strPathProjectFileEx;};
	wxString getStrLayerType(){return strLayerType;};
	wxString getStrLayerAverage(){return strLayerAverage;};
	wxString getStrChani(){return strChani;};
	wxString getStrVerticalK(){return strVerticalK;};
	wxString getStrWetting(){return strWetting;};
	void getConductivityFlags(int intConstantHKValueFlag[], int intConstantVKValueFlag[], int intConstantSSValueFlag[]);
	void getConductivityValues(double dblConstantHKValue[], double dblConstantVKValue[], double dblConstantSSValue[]);
	long getIntPointsPerSlice(){return intPntPSlice;};
	void getConstRecharge(int intConstRechFlag[], double dblConstRechValue[]);
	int getOCSaveAllLayers(){return intOCSaveAllLayers;};
	int getOCSaveAllPeriods(){return intOCSaveAllPeriods;};
	int getOCSaveSingleLayer(){return intOCSaveLayer;}; 
	int getOCSaveSinglePeriod(){return intOCSavePeriod;};
	wxString getStrProjName(){return strProjName;};
	void getStressPeriodData(double dblStressPLength[], double dblTimeStepLength[], int intTimeMode[]);
	wxString getTopLayer(){return strTopLayer;};
	void getLayerParameters(wxString strLayerBot[], wxString strLayerHCond[], wxString strLayerVCond[], wxString strLayerSpecStor[], wxString strLayerBC[], wxString strLayerIH[]);
	void getPeriodParameters(wxString strStreePeriod[], double dblTimeStepLength2[], int intTimeMode2[], wxString strRech[], wxString strWells[]);
	wxString getSaveResLayer(){return strSaveResLay;};
	wxString getSaveResStrePer(){return strSaveResStrePer;};
	wxString getOuterIter(){return strOuterIter;};
	wxString getInnerIter(){return strInnerIter;};
	wxString getHeadChangeCrit(){return strHeadChangeCrit;};
	wxString getResCrit(){return strResCrit;};
	
	
/* 	

  for(counter=0;counter<intNPER;counter++)
  {
    strSaveString<<WxListBoxStressPeriods->GetString(counter)<<"\n";
    strSaveString<<vTimeStepLength[counter]<<"\n";
    strSaveString<<vTimeMode[counter]<<"\n";
    strSaveString<<WxListBoxRech->GetString(counter)<<"\n";
    strSaveString<<WxListBoxWells->GetString(counter)<<"\n";
    
  }
  
      strSaveString<<WxListBoxSaveResLayers->GetString(0)<<"\n";
      strSaveString<<WxListBoxSaveResStressPeriods->GetString(0)<<"\n";
  
  strSaveString<<WxEditOuterIter->GetValue()<<"\n";
  strSaveString<<WxEditInnerIterations->GetValue()<<"\n";
  strSaveString<<WxEditHeadChangeCrit->GetValue()<<"\n";
  strSaveString<<WxEditResidualCrit->GetValue()<<"\n";*/
        
        
    private:
      long intNumPer;  
      long intITMUnits;
      long intLengthUnits;
      long intNumLayers;
      long intNumRows;
      long intNumCols;
      long *lngIntNumStep;
      long intTimeStepMulti;
      long intSavePeriods;
      double dblPerLen;
      double dblTimeUnitMult;
      double dblLengthUnitMult;
      double dblXRasterDistance;
      double dblYRasterDistance;
      double dblRechMult;
      double dblDisMult;
      double dblXRasterMin;
      double dblYRasterMin;
      wxString strPathProjectFile;
      wxString strPathProjectFileEx;
      wxString strPathProjectFilePost;
      wxString strPathProjectFilePre;
      wxString strLayerType;
      wxString strLayerAverage;
      wxString strChani;
      wxString strVerticalK;
      wxString strWetting;
      int *intConstantHKValueFlag;
      int *intConstantVKValueFlag;
      int *intConstantSSValueFlag;
      double *dblConstantHKValue;
      double *dblConstantVKValue;
      double *dblConstantSSValue;
      long intPntPSlice;
      int *intConstantRechValueFlag;
      double *dblConstantRechValue;
      int intOCSaveAllLayers;
      int intOCSaveAllPeriods;
      int intOCSaveLayer;
      int intOCSavePeriod;
      wxString strProjName;
      double *dblStressPLength;
      double *dblTimeStepLength;
      int *intTimeMode;
      wxString strTopLayer;
      wxString *strLayerBot;
      wxString *strLayerHCond;
      wxString *strLayerVCond;
      wxString *strLayerSpecStor;
      wxString *strLayerBC;
      wxString *strLayerIH;
      wxString *strStreePeriod;
      double *dblTimeStepLength2;
      int *intTimeMode2;
      wxString *strRech; 
      wxString *strWells;
      wxString strSaveResLay;
      wxString strSaveResStrePer;
      wxString strOuterIter;
      wxString strInnerIter;
      wxString strHeadChangeCrit;
      wxString strResCrit;
      
      
/*      long numGRIDS;
        wxString *namesGRIDS;
	wxString *typeGRIDS;
	wxString *layerName;
	long *r;
	long *g;
	long *b;
        wxString vertScale3D;
        wxString horScale3D;
        wxString vertScale2D;
        wxString horScale2D;
        wxString vertScale1D;
        wxString horAngle3D;
        wxString vertAngle3D;
        wxString offset3D;
        wxString fileStringCrossSectionLine;
        wxString xCoordinate1D;
        wxString yCoordinate1D;
        wxString xCoordVBore;
        wxString yCoordVBore;	*/
};